@@ -106,6 +106,12 @@ pub enum AgentError {
     #[error("The invocation to the wallet call forward method failed with the error: {0}")]
     WalletCallFailed(String),
 
+    #[error("The  wallet operation failed: {0}")]
+    WalletError(String),
+
+    #[error("The wallet canister must be upgraded: {0}")]
+    WalletUpgradeRequired(String),
+
     #[error("Missing replica transport in the Agent Builder.")]
     MissingReplicaTransport(),
 
