@@ -110,7 +110,7 @@ pub struct ReadStateResponse {
 
 /// A `Certificate` as defined in https://docs.dfinity.systems/public/#_certificate
 #[derive(Deserialize)]
-pub(crate) struct Certificate<'a> {
+pub struct Certificate<'a> {
     pub tree: HashTree<'a>,
 
     #[serde(with = "serde_bytes")]
@@ -120,7 +120,7 @@ pub(crate) struct Certificate<'a> {
 }
 
 #[derive(Deserialize)]
-pub(crate) struct Delegation {
+pub struct Delegation {
     #[serde(with = "serde_bytes")]
     pub subnet_id: Vec<u8>,
 
